# -*- coding: utf-8 -*-
"""
    flask_konch
    ~~~~~~~~~~~

    An improved shell commmand for the Flask CLI.

    :copyright: (c) 2016 by Steven Loria
    :license: MIT, see LICENSE for more details.
"""
__version__ = '1.1.0'
__author__ = 'Steven Loria'
__license__ = 'MIT'

__all__ = [
    'EXTENSION_NAME',
]

EXTENSION_NAME = 'flask-konch'
